tiled.client.xarray.DatasetClient
=================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DatasetClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DatasetClient.__init__
      ~DatasetClient.download
      ~DatasetClient.export
      ~DatasetClient.new_variation
      ~DatasetClient.read
      ~DatasetClient.refresh
      ~DatasetClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DatasetClient.context
      ~DatasetClient.coords
      ~DatasetClient.data_vars
      ~DatasetClient.formats
      ~DatasetClient.item
      ~DatasetClient.metadata
      ~DatasetClient.offline
      ~DatasetClient.path
      ~DatasetClient.uri
      ~DatasetClient.username
   
   